---
name: Enhancement
about: Enhance an existing component.
title: ''
labels: enhancement
assignees: ''

---

* pybaum version used, if any:
* Python version, if any:
* Operating System:

### What would you like to enhance and why? Is it related to an issue/problem?

A clear and concise description of the current implementation and its limitations.

### Describe the solution you'd like

A clear and concise description of what you want to happen.

### Describe alternatives you've considered

A clear and concise description of any alternative solutions or features you've
considered and why you have discarded them.
